**Jun 20, 2022.** In anticipation for the Version 1.1, we have released a new release candidate
with some fixes and improvements.

See the :ref:`complete list of changes here <version-1-1>`.
..end-first-page